# testnet
# export ETH_CHAIN_ID="5"
# export PAY="https://api-dev.everpay.io"
# export PERMA_WS="wss://router0-dev.permaswap.network/wslp"
# export PERMA_HTTP="https://router0-dev.permaswap.network"

# mainnet
export ETH_CHAIN_ID="1"
export PAY="https://api.everpay.io"
export PERMA_WS="wss://router.permaswap.network/wslp"
export PERMA_HTTP="https://router.permaswap.network"

export LP_CONFIG="./lp_config.json"

# private key of your eth account
export ECC_PRIVATE=""
# if use arweave account, set your ar wallet file path
# export AR_WALLET="ar_wallet.json"
./lp

